==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>看圖</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>看圖是一款外觀時尚，性能流暢的圖片查看工具。</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>張圖片</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>此文件包含多個頁面，推薦使用文檔查看器查看所有頁面。</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>打開圖片目錄</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>沒有權限查看圖片</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>圖片類型</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改時間</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>尺寸</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍攝時間</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光時間</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>閃光燈</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>測光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>閃光燈補償</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>鏡頭型號</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>顏色空間</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相機型號</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>圖片尺寸</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>標記</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>無縮放</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>頁面適應圖像</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>圖像適應頁面</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>縮放至：</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>毫米</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>厘米</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>英吋</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>圖像位置</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>縮放</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>圖像設置</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>圖像設置</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>百葉窗</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>開關</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>滑移</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>圓環</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>請輸入圖片名稱</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>選擇目錄</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>該目錄不支持同步</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>添加文件夾</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>同步目錄管理</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>目錄列表為空</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>取消同步</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>張圖片</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>移動設備已被移除</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>該目錄已不存在</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>正在計算...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>查看圖片</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相冊</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>退出幻燈片</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>上一屏</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>下一屏</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>放大圖片</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>縮小圖片</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>請輸入新的快捷鍵</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>查看圖片</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相冊</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>恢復默認</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>退出幻燈片</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>幻燈片設置</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>切換效果</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>時間</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>切換時間</translation>
    </message>
    <message>
        <source>second</source>
        <translation>秒</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1視圖</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>適應窗口</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>圖片管理</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1視圖</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>適應窗口</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>打開圖片</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>幻燈片設置</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>效果</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>時間</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>相冊</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>時間線</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>添加到相冊</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>添加到新相冊</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>顯示導航窗口</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>隱藏導航窗口</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>打開圖片</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>所有圖片</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>畫板</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.6.orig.tar.xz: deepin-image-viewer-5.9.6/src/translations/deepin-image-viewer_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>打開圖片</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>查看圖片</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>放大圖片</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>縮小圖片</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>看圖</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>看圖是一款外觀時尚，性能流暢的圖片查看工具。</translation>
    </message>
</context>
</TS>
